import { Events } from "./events";
import { OsanoPromises } from "./osano-promises";
import { EventRegister } from "@tecnavia/react-native-event-listeners";
import { CmpStorage, DateUtils } from "@tecnavia/react-native-utils";
let hook;
let configurationToConsume;
export let OsanoHook;
(function (_OsanoHook) {
  const consumeConfiguration = _OsanoHook.consumeConfiguration = () => {
    var _hook;
    if (!configurationToConsume) return;
    (_hook = hook) === null || _hook === void 0 || _hook(configurationToConsume);
    configurationToConsume = undefined;
  };
  const setHook = _OsanoHook.setHook = cb => {
    hook = cb;
    consumeConfiguration();
  };
})(OsanoHook || (OsanoHook = {}));
/**
 * This interface is used to interact with the Osano component
 * You should add only methods that you want to expose outside of the library
 */
export let Osano;
(function (_Osano) {
  /**
   * This method is used to update the configuration of the Osano component
   * Could trigger a re-render of the component, Osano could appear
   * With this params to see the consent use Container callbacks
   */
  const update = value => {
    var _hook2;
    if (!hook) {
      configurationToConsume = value;
      return;
    }
    configurationToConsume = undefined;
    (_hook2 = hook) === null || _hook2 === void 0 || _hook2(value);
  };

  /**
   * This method save the promise and trigger the event, see osano-ui.tsx
   * The promise will be resolved when the webview will send the data to the app
   */
  const askTcData = _Osano.askTcData = async () => {
    const result = await OsanoPromises.make("tcData", true, () => {
      EventRegister.emit(Events.ASK_TC_DATA);
    });
    let vendorList;
    try {
      vendorList = await askVendorListData();
    } catch (e) {
      console.error("Error asking vendor list", e);
    }
    await CmpStorage.setTCData(result, vendorList);
    return result;
  };
  const askUspData = _Osano.askUspData = async () => {
    const result = await OsanoPromises.make("uspData", true, () => {
      EventRegister.emit(Events.ASK_USP_DATA);
    });
    await CmpStorage.setUSPData(result);
    return result;
  };
  const askConsentData = _Osano.askConsentData = async () => {
    return OsanoPromises.make("consentData", true, () => {
      EventRegister.emit(Events.ASK_CONSENT_DATA);
    });
  };
  const askVendorListData = _Osano.askVendorListData = async () => {
    return OsanoPromises.make("vendorListData", true, () => {
      EventRegister.emit(Events.ASK_VENDOR_LIST_DATA);
    });
  };
  const ask = _Osano.ask = async configuration => {
    if (!configuration.customerId) throw new Error("Missing customerId, can't retrieve script");
    if (!configuration.projectId) throw new Error("Missing projectId, can't retrieve script");
    if (!configuration.siteDomain) throw new Error("Missing siteDomain, can't store cookies without it");
    const result = await OsanoPromises.make("askConsent", false, () => {
      update(configuration);
    });
    await updateData();
    const timestamp = await getConsentDate();
    if (configuration.resetConsentDate && timestamp) {
      //clear local data if necessary
      const consentDate = DateUtils.getDateString(timestamp, "YYYYMMDD");
      if (consentDate < configuration.resetConsentDate) {
        await clear();
        showDialog();
      }
    }
    return result;
  };
  const destroy = _Osano.destroy = () => {
    var _hook3;
    (_hook3 = hook) === null || _hook3 === void 0 || _hook3(undefined);
  };
  const updateData = _Osano.updateData = () => Promise.all([askTcData(), askUspData()]);
  const change = _Osano.change = async () => {
    const result = await OsanoPromises.make("changeConsent", false, () => {
      EventRegister.emit(Events.CHANGE_CONSENT);
    });
    await updateData();
    return result;
  };
  const showDrawer = _Osano.showDrawer = () => {
    EventRegister.emit(Events.SHOW_DRAWER);
  };
  const showDialog = _Osano.showDialog = () => {
    EventRegister.emit(Events.SHOW_DIALOG);
  };
  const clear = _Osano.clear = async () => {
    EventRegister.emit(Events.CLEAR_CONSENT);
    await CmpStorage.clearAll();
  };
  const getConsentDate = _Osano.getConsentDate = async () => {
    const result = await OsanoPromises.make("getConsentDate", true, () => {
      EventRegister.emit(Events.GET_CONSENT_DATE);
    });
    return result;
  };
})(Osano || (Osano = {}));
//# sourceMappingURL=osano.js.map